======================
:mod:`pyCTQW.MPI.ctqw`
======================

.. currentmodule:: pyCTQW.MPI.ctqw

.. automodule:: pyCTQW.MPI.ctqw

.. caution::
  The functions available in this submodule have been
  designed to work with classes in the :class:`pyCTQW.MPI` module; that is, they are
  being called implicitly by the above classes, invisible to the user.
  
  It is not recommended that they be used by themselves, however it is
  possible to do so.

Class Summary
--------------

.. autosummary::
	:toctree: stub
	:template: class.rst

	EigSolver
	Hamiltonian
	QuantumWalkP1
	QuantumWalkP2
	QuantumWalkP3
	entanglementHandle
	nodeHandle